==> BSgenome.Amellifera.BeeBase.assembly4_1.3.11.tar.gz: BSgenome.Amellifera.BeeBase.assembly4/man/package.Rd <==
\name{Amellifera}
\docType{package}

\alias{BSgenome.Amellifera.BeeBase.assembly4-package}
\alias{BSgenome.Amellifera.BeeBase.assembly4}
\alias{Amellifera}


\title{Apis mellifera (Honey Bee) full genome (BeeBase assembly4)}

\description{
  Apis mellifera (Honey Bee) full genome as provided by BeeBase (assembly4, Feb. 2008) and stored in Biostrings objects.
}

\details{
  
}

\note{
  This BSgenome data package was made from the following source data files:
  \preformatted{
-- information not available --

  }
  See \code{?\link[BSgenome]{BSgenomeForge}} and the BSgenomeForge
  vignette (\code{vignette("BSgenomeForge")}) in the BSgenome software
  package for how to make a BSgenome data package.
}

\author{H. Pages}

\seealso{
  \link[BSgenome]{BSgenome-class},
  \link[Biostrings]{DNAString-class},
  \code{\link[BSgenome]{available.genomes}},
  \link[BSgenome]{BSgenomeForge}
}

\examples{
Amellifera
seqlengths(Amellifera)
Amellifera$Group1  # same as Amellifera[["Group1"]]

if ("AGAPS" \%in\% masknames(Amellifera)) {

  ## Check that the assembly gaps contain only Ns:
  checkOnlyNsInGaps <- function(seq)
  {
    ## Replace all masks by the inverted AGAPS mask
    masks(seq) <- gaps(masks(seq)["AGAPS"])
    af <- alphabetFrequency(seq)
    found_letters <- names(af)[af != 0]
    if (any(found_letters != "N"))
        stop("assembly gaps contain more than just Ns")
  }

  ## A message will be printed each time a sequence is removed
  ## from the cache:
  options(verbose=TRUE)

  for (seqname in seqnames(Amellifera)) {
    cat("Checking sequence", seqname, "... ")
    seq <- Amellifera[[seqname]]
    checkOnlyNsInGaps(seq)
    cat("OK\n")
  }
}

## See the GenomeSearching vignette in the BSgenome software
## package for some examples of genome-wide motif searching using
## Biostrings and the BSgenome data packages:
if (interactive())
    vignette("GenomeSearching", package="BSgenome")
}

\keyword{package}
\keyword{data}

==> BSgenome.Amellifera.BeeBase.assembly4_1.3.16.tar.gz: BSgenome.Amellifera.BeeBase.assembly4/man/package.Rd <==
\name{Amellifera}
\docType{package}

\alias{BSgenome.Amellifera.BeeBase.assembly4-package}
\alias{BSgenome.Amellifera.BeeBase.assembly4}
\alias{Amellifera}


\title{Apis mellifera (Honey Bee) full genome (BeeBase assembly4)}

\description{
  Apis mellifera (Honey Bee) full genome as provided by BeeBase (assembly4, Feb. 2008) and stored in Biostrings objects.
}

\details{
  
}

\note{
  This BSgenome data package was made from the following source data files:
  \preformatted{
-- information not available --

  }
  See \code{?\link[BSgenome]{BSgenomeForge}} and the BSgenomeForge
  vignette (\code{vignette("BSgenomeForge")}) in the BSgenome software
  package for how to make a BSgenome data package.
}

\author{H. Pages}

\seealso{
  \link[BSgenome]{BSgenome-class},
  \link[Biostrings]{DNAString-class},
  \code{\link[BSgenome]{available.genomes}},
  \link[BSgenome]{BSgenomeForge}
}

\examples{
Amellifera
seqlengths(Amellifera)
Amellifera$Group1  # same as Amellifera[["Group1"]]

if ("AGAPS" \%in\% masknames(Amellifera)) {

  ## Check that the assembly gaps contain only Ns:
  checkOnlyNsInGaps <- function(seq)
  {
    ## Replace all masks by the inverted AGAPS mask
    masks(seq) <- gaps(masks(seq)["AGAPS"])
    unique_letters <- uniqueLetters(seq)
    if (any(unique_letters != "N"))
        stop("assembly gaps contain more than just Ns")
  }

  ## A message will be printed each time a sequence is removed
  ## from the cache:
  options(verbose=TRUE)

  for (seqname in seqnames(Amellifera)) {
    cat("Checking sequence", seqname, "... ")
    seq <- Amellifera[[seqname]]
    checkOnlyNsInGaps(seq)
    cat("OK\n")
  }
}

## See the GenomeSearching vignette in the BSgenome software
## package for some examples of genome-wide motif searching using
## Biostrings and the BSgenome data packages:
if (interactive())
    vignette("GenomeSearching", package="BSgenome")
}

\keyword{package}
\keyword{data}
